@@ -9,4 +9,9 @@ def test_load_skills_registers_handlers():
     skills_path = Path(__file__).resolve().parent.parent / "data" / "skills.json"
     load_skills(skills_path)
     assert "fireball" in skill_registry.skills
-    assert skill_registry.handlers["fireball"](None, None) == 42
+    assert "fireball" in skill_registry.handlers
+    assert callable(skill_registry.handlers["fireball"])
+
+    from mud.skills import handlers as skill_handlers
+
+    assert skill_registry.handlers["fireball"] is skill_handlers.fireball
